@@ -64,7 +64,7 @@ class RedisCache:
             try:
                 redis_connection.hset(redis_key, _hash_key, str(_hash_value))
             except Exception as e:
-                self.exception_log(e, "RedisCache->put_value_in_hash_set()->>")
+                self.exception(e, "RedisCache->put_value_in_hash_set()->>")
                 raise RGRedisException("RedisCache->put_value_in_hash_set()->>" + self.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=put_value_in_hash_set")
@@ -146,11 +146,13 @@ class RedisCache:
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=incr_value")
 
-    def get_exception_msg(self, e) -> str:
+    @classmethod
+    def exception(cls, e, log_message: str = "", can_print_stacktrace: bool = False):
+        logger.error("%s, ExceptionMessage:%s", log_message, cls.get_exception_msg(e), exc_info=can_print_stacktrace)
+
+    @classmethod
+    def get_exception_msg(cls, e) -> str:
         try:
             return getattr(e, 'message', repr(e))
         except Exception as e:
             return getattr(e, 'message', repr(e))
-
-    def exception_log(self, e, log_message: str = "", can_print_stacktrace: bool = False):
-        logger.error("%s, ExceptionMessage:%s", log_message, self.get_exception_msg(e), exc_info=can_print_stacktrace)
